//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Views/DataView.cpp
//! @brief     Implements class DataView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Views/DataView.h"
#include "GUI/Model/Data/DataItem.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/Model/Files/DatafilesSet.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/View/Frame/StackedFrames.h"
#include "GUI/View/List/DatafilesSelector.h"
#include <QSplitter>
#include <QVBoxLayout>

DataView::DataView()
{
    auto* layout = new QVBoxLayout(this);

    auto* splitter = new QSplitter;
    layout->addWidget(splitter);

    auto* stacked_frames = new StackedDataFrames;
    auto* selector = new DatafilesSelector;

    splitter->addWidget(selector);
    splitter->addWidget(stacked_frames);

    splitter->setCollapsible(0, false);
    splitter->setCollapsible(1, false);

    if (const DatafileItem* dfi = gDoc->datafiles()->currentItem())
        stacked_frames->setStackedItem(dfi->dataItem());

    connect(gDoc->datafiles(), &DatafilesSet::setChanged, [stacked_frames] {
        const DatafileItem* dfi = gDoc->datafiles()->currentItem();
        stacked_frames->setStackedItem(dfi ? dfi->dataItem() : nullptr);
    });
}
